CREATE TABLE IF NOT EXISTS "areas" (
    "area" character varying(20) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "abbreviation" character varying(10) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "default" boolean NOT NULL DEFAULT false,
    "rank" integer DEFAULT NULL,
    "coordinates" character varying(30) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    CONSTRAINT "areas_pkey" PRIMARY KEY ("area"),
    CONSTRAINT "areas_rank_unique" UNIQUE ("rank")
);
CREATE TABLE IF NOT EXISTS "changelog" (
    "id" serial NOT NULL,
    "when" timestamp NOT NULL,
    "who" integer NOT NULL,
    "log_version" integer NOT NULL DEFAULT 1, -- TODO this was added to the schema
    "table" character varying(255) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "id_key" character varying(64) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "id_value" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "field" character varying(255) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "value_old" text COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "value_new" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "executed" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    CONSTRAINT "changelog_pkey" PRIMARY KEY ("id")
);
CREATE TABLE IF NOT EXISTS "chapters" (
    "id" serial NOT NULL,
    "lecture_id" integer NOT NULL,
    "time" integer NOT NULL,
    "text" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "visible" boolean NOT NULL DEFAULT false, -- TODO info: was integer
    "deleted" boolean NOT NULL DEFAULT false, -- TODO info: was integer
    "time_created" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, -- TODO info: default was not present
    "time_updated" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, -- TODO info: default was not present
    "created_by" integer DEFAULT NULL,
    "submitted_by" character varying(32) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    CONSTRAINT "chapters_pkey" PRIMARY KEY ("id")
);
CREATE TABLE IF NOT EXISTS "courses_data" (
    "id" serial NOT NULL,
    "visible" boolean NOT NULL DEFAULT false,
    "listed" boolean NOT NULL DEFAULT true,
    "deleted" boolean NOT NULL DEFAULT false,
    "title" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "short" character varying(32) COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "handle" character varying(32) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "organizer" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "subject" character varying(32) COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "credits" smallint NOT NULL DEFAULT 0,
    "created_by" integer DEFAULT NULL,
    "time_created" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, -- TODO info: default was not present
    "time_updated" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, -- TODO info: default was not present
    "semester" character varying(6) NOT NULL DEFAULT '',
    "settings" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "downloadable" boolean NOT NULL DEFAULT true,
    "embedinvisible" boolean NOT NULL DEFAULT false,
    "description" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "internal" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "responsible" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "feed_url" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "external" boolean NOT NULL DEFAULT false, -- TODO info: was integer
    "coursechapters" boolean NOT NULL DEFAULT false, -- TODO info: was integer
    "autopublish" boolean NOT NULL DEFAULT false,
    "autovisible" boolean NOT NULL DEFAULT false,
    "profile" character varying(64) COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT 'default',
    "login_info" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    CONSTRAINT "courses_data_pkey" PRIMARY KEY ("id")
);
CREATE INDEX IF NOT EXISTS "courses_data_semester_index" ON "courses_data" ("semester");
CREATE INDEX IF NOT EXISTS "courses_data_subject_index" ON "courses_data" ("subject");
CREATE INDEX IF NOT EXISTS "courses_data_visible_index" ON "courses_data" ("visible");
COMMENT ON COLUMN "courses_data"."semester" IS 'format: 2009ws';
COMMENT ON COLUMN "courses_data"."settings" IS 'used by site import';

CREATE TABLE IF NOT EXISTS "filesizes" (
    "path" character varying(255) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "size" bigint NOT NULL DEFAULT 0,
    "duration" real DEFAULT NULL,
    "basename" character varying(255) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    CONSTRAINT "filesizes_pkey" PRIMARY KEY ("path")
);
CREATE INDEX IF NOT EXISTS "filesizes_basename_index" ON "filesizes" ("basename");
CREATE INDEX IF NOT EXISTS "filesizes_size_index" ON "filesizes" ("size");
CREATE INDEX IF NOT EXISTS "filesizes_duration_index" ON "filesizes" ("duration");
COMMENT ON COLUMN "filesizes"."duration" IS 'Sekunden';

CREATE TABLE IF NOT EXISTS "formats" (
    "id" serial NOT NULL,
    "description" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "keywords" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "resolution" character varying(16) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "aspect" character varying(16) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "prio" integer NOT NULL DEFAULT 0,
    "player_prio" integer NOT NULL DEFAULT 0,
    "mimetype" character varying(32) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "options" text COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "suffix" character varying(32) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    CONSTRAINT "formats_pkey" PRIMARY KEY ("id")
);
CREATE INDEX IF NOT EXISTS "formats_resolution_index" ON "formats" ("resolution");
CREATE INDEX IF NOT EXISTS "formats_aspect_index" ON "formats" ("aspect");

CREATE TYPE "drehplan_enum" AS ENUM ('egal', 'ja', 'nein');
CREATE TABLE IF NOT EXISTS "lectures_data" (
    "id" serial NOT NULL,
    "course_id" integer NOT NULL,
    "visible" boolean NOT NULL DEFAULT true,
    "timed_release" timestamp DEFAULT NULL,
    "use_timed_release" boolean NOT NULL DEFAULT false,
    "drehplan" drehplan_enum NOT NULL DEFAULT 'ja',
    "deleted" boolean NOT NULL DEFAULT false,
    "title" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "comment" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "internal" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "speaker" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "place" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "time" timestamp NOT NULL,
    "duration" integer NOT NULL DEFAULT 90,
    "time_created" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, -- TODO info: default was not present
    "time_updated" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, -- TODO info: default was not present
    "jumplist" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "titlefile" character varying(255) COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "live" boolean NOT NULL DEFAULT false, -- TODO info: was integer
    "norecording" boolean NOT NULL DEFAULT false, -- TODO info: was integer
    "profile" character varying(64) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "stream_settings" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "stream_job" integer DEFAULT NULL,
    CONSTRAINT "lectures_data_pkey" PRIMARY KEY ("id")
);
CREATE INDEX IF NOT EXISTS "lectures_data_course_id_index" ON "lectures_data" ("course_id");
CREATE INDEX IF NOT EXISTS "lectures_data_time_index" ON "lectures_data" ("time");
CREATE INDEX IF NOT EXISTS "lectures_data_visible_index" ON "lectures_data" ("visible");
CREATE INDEX IF NOT EXISTS "lectures_data_use_timed_release_index" ON "lectures_data" ("use_timed_release");
CREATE INDEX IF NOT EXISTS "lectures_data_timed_release_index" ON "lectures_data" ("timed_release");
COMMENT ON TABLE "lectures_data" IS 'einzelne Vorlesungen; TODO: videos.source kopieren';
COMMENT ON COLUMN "lectures_data"."duration" IS 'in Minuten';
COMMENT ON COLUMN "lectures_data"."jumplist" IS 'liste fuer kapitelmarker';
COMMENT ON COLUMN "lectures_data"."titlefile" IS 'Bilddatei';

CREATE TABLE IF NOT EXISTS "places" (
    "place" character varying(20) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "name" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "area" character varying(20) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "campus_room" character varying(20) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "campus_name" character varying(30) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    CONSTRAINT "places_pkey" PRIMARY KEY ("place")
);
CREATE INDEX IF NOT EXISTS "places_area_index" ON "places" ("area");

CREATE TABLE IF NOT EXISTS "perm" (
    "id" serial NOT NULL,
    "deleted" boolean NOT NULL DEFAULT false, -- TODO info: was integer
    "course_id" integer DEFAULT NULL,
    "lecture_id" integer DEFAULT NULL,
    "video_id" integer DEFAULT NULL,
    "type" character varying(10) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "param1" character varying(127) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "param2" character varying(127) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "time_created" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, -- TODO info: default was not present
    "time_updated" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, -- TODO info: default was not present
    "created_by" integer DEFAULT NULL,
    CONSTRAINT "perm_pkey" PRIMARY KEY ("id")
);

CREATE TABLE IF NOT EXISTS "site_texts" (
    "key" character varying(64) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "value" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "modified_when" timestamp NOT NULL,
    "modified_by" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    CONSTRAINT "site_texts_pkey" PRIMARY KEY ("key")
);

CREATE TABLE IF NOT EXISTS "sources" (
    "id" serial NOT NULL,
    "lecture_id" integer NOT NULL,
    "path" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "type" text COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "hash" character varying(32) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "time_created" timestamp NOT NULL,
    CONSTRAINT "sources_pkey" PRIMARY KEY ("id")
); -- TODO info: this had collation latin1_swedish_ci

CREATE TABLE IF NOT EXISTS "log" (
    "logid" bigserial NOT NULL,
    "id" bigint NOT NULL,
    "time" timestamp NOT NULL,
    "date" date NOT NULL,
    "source" boolean NOT NULL DEFAULT false,
    "video" integer NOT NULL,
    CONSTRAINT "log_pkey" PRIMARY KEY ("logid")
);
CREATE INDEX IF NOT EXISTS "date_index" ON "log" ("date");
CREATE INDEX IF NOT EXISTS "video_index" ON "log" ("video");

CREATE TABLE IF NOT EXISTS "hlslog" (
    "logid" serial NOT NULL,
    "id" bigint NOT NULL,
    "time" timestamp NOT NULL,
    "segment" integer NOT NULL,
    "lecture" integer NOT NULL,
    "handle" character varying(32) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "format" character varying(16) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    CONSTRAINT "hlslog_pkey" PRIMARY KEY ("logid")
);

CREATE TABLE IF NOT EXISTS "logcache" (
    "id" serial NOT NULL,
    "req" character varying(64) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "param" character varying(64) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "trace" character varying(64) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "date" date NOT NULL,
    "value" integer NOT NULL,
    CONSTRAINT "logcache_pkey" PRIMARY KEY ("id")
);

CREATE TABLE IF NOT EXISTS "profiles" (
    "id" serial NOT NULL,
    "name" character varying(64) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "format" integer NOT NULL,
    CONSTRAINT "profiles_pkey" PRIMARY KEY ("id")
); -- TODO info: this had collation latin1_swedish_ci

CREATE TABLE IF NOT EXISTS "streams" (
    "handle" character varying(32) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "active" boolean NOT NULL,
    "visible" boolean NOT NULL,
    "lecture_id" integer NOT NULL,
    "description" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "poster" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "job_id" integer DEFAULT NULL
); -- TODO a primary key is missing here ?
CREATE UNIQUE INDEX IF NOT EXISTS "streams_handle_index" ON "streams" ("handle");
COMMENT ON COLUMN "streams"."handle" IS 'RTMP tag und course-Handle';
COMMENT ON COLUMN "streams"."lecture_id" IS 'Wird generiert beim Streamstart';

CREATE TABLE IF NOT EXISTS "live_sources" (
    "id" serial NOT NULL,
    "key" character varying(32) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "preview_key" character varying(32) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "name" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "description" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "options" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "server" character varying(32) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "server_public" character varying(32) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "clientid" integer DEFAULT NULL,
    "last_active" timestamp DEFAULT NULL,
    "time_created" timestamp NOT NULL,
    "time_updated" timestamp NOT NULL,
    "created_by" integer NOT NULL,
    "deleted" boolean NOT NULL DEFAULT false,
    CONSTRAINT "live_sources_pkey" PRIMARY KEY ("id")
);
CREATE UNIQUE INDEX IF NOT EXISTS "live_sources_key_index" ON "live_sources" ("key");

CREATE TABLE IF NOT EXISTS "stream_stats" (
    "id" serial NOT NULL,
    "handle" character varying(32) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "lecture" integer NOT NULL,
    "time" timestamp NOT NULL,
    "rtmp_h264" integer NOT NULL DEFAULT 0,
    "http_webm" integer NOT NULL DEFAULT 0,
    "hls_1080p" integer NOT NULL DEFAULT 0,
    "hls_720p" integer NOT NULL DEFAULT 0,
    "hls_360p" integer NOT NULL DEFAULT 0,
    CONSTRAINT "stream_stats_pkey" PRIMARY KEY ("id")
);
CREATE INDEX IF NOT EXISTS "stream_stats_handle_index" ON "stream_stats" ("handle");
CREATE INDEX IF NOT EXISTS "stream_stats_time_index" ON "stream_stats" ("time");

CREATE TABLE IF NOT EXISTS "import_campus" (
    "id" serial NOT NULL,
    "course_id" integer NOT NULL,
    "last_checked" timestamp NOT NULL,
    "type" character varying(255) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "url" character varying(2084) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "changed" integer NOT NULL DEFAULT 0,
    CONSTRAINT "import_campus_pkey" PRIMARY KEY ("id")
);

CREATE TABLE IF NOT EXISTS "users" (
    "id" serial NOT NULL,
    "name" character varying(32) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "realname" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "level" integer NOT NULL DEFAULT 0,
    "fsacc" character varying(32) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "last_login" timestamp DEFAULT NULL,
    "calendar_key" character varying(40) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "rfc6238" character varying(20) COLLATE "pg_catalog"."und-x-icu" NOT NULL, -- TODO info: this had ascii character set and ascii_bin collation
    "mail_notifications" boolean NOT NULL DEFAULT false,
    "time_updated" timestamp DEFAULT NULL,
    "notify_chapter_submitted" boolean NOT NULL DEFAULT true,
    "notify_new_video" boolean NOT NULL DEFAULT true,
    "notify_edit" boolean NOT NULL DEFAULT false,
    CONSTRAINT "users_pkey" PRIMARY KEY ("id")
);
COMMENT ON COLUMN "users"."level" IS '1 ist readonly, 2 ist normal, 3 ist zum debuggen';
COMMENT ON COLUMN "users"."fsacc" IS 'zum dateibesitzer zuordnen';
COMMENT ON COLUMN "users"."rfc6238" IS '2FA als TAN';
COMMENT ON TABLE "users" IS 'bitte niemanden loeschen, da haengen weitere daten dran';

CREATE TABLE IF NOT EXISTS "videos_data" (
    "id" serial NOT NULL,
    "lecture_id" integer NOT NULL,
    "visible" boolean NOT NULL DEFAULT true,
    "deleted" boolean NOT NULL DEFAULT false,
    "downloadable" boolean NOT NULL DEFAULT true,
    "title" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "comment" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "internal" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "path" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "file_modified" timestamp NOT NULL,
    "time_created" timestamp NOT NULL,
    "time_updated" timestamp NOT NULL,
    "created_by" integer NOT NULL,
    "file_size" bigint NOT NULL DEFAULT -1,
    "video_format" integer NOT NULL,
    "hash" character varying(32) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "source" integer DEFAULT NULL,
    "duration" integer NOT NULL,
    CONSTRAINT "videos_data_pkey" PRIMARY KEY ("id")
); -- TODO this had ROW_FORMAT=COMPACT
CREATE INDEX IF NOT EXISTS "videos_data_hash_index" ON "videos_data" ("hash");
CREATE INDEX IF NOT EXISTS "videos_data_video_format_index" ON "videos_data" ("video_format");
CREATE INDEX IF NOT EXISTS "videos_data_file_size_index" ON "videos_data" ("file_size");
CREATE INDEX IF NOT EXISTS "videos_data_time_updated_index" ON "videos_data" ("time_updated");
CREATE INDEX IF NOT EXISTS "videos_data_lecture_id_index" ON "videos_data" ("lecture_id");
CREATE INDEX IF NOT EXISTS "videos_data_deleted_index" ON "videos_data" ("deleted");
COMMENT ON TABLE "videos_data" IS 'TODO: source nach lectures kopieren';

CREATE TABLE IF NOT EXISTS "announcements" (
    "id" serial NOT NULL,
    "extid" character varying(128) COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "text" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "level" integer NOT NULL DEFAULT 0,
    "visible" boolean NOT NULL DEFAULT false, -- TODO info: was integer
    "deleted" boolean NOT NULL DEFAULT false, -- TODO info: was integer
    "time_publish" timestamp DEFAULT NULL,
    "time_expire" timestamp DEFAULT NULL,
    "time_created" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, -- TODO info: default was not present
    "time_updated" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, -- TODO info: default was not present
    "created_by" integer NOT NULL DEFAULT -1, -- TODO info: default was not present
    CONSTRAINT "announcements_pkey" PRIMARY KEY ("id")
);
CREATE UNIQUE INDEX IF NOT EXISTS "announcements_extid_index" ON "announcements" ("extid");

CREATE TABLE IF NOT EXISTS "featured" (
    "id" serial NOT NULL,
    "title" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "text" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "internal" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "type" character varying(32) COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "param" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "order" integer NOT NULL DEFAULT 0, -- TODO info: default was not present
    "param2" text COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT '',
    "visible" boolean NOT NULL DEFAULT false, -- TODO info: was integer
    "deleted" boolean NOT NULL DEFAULT false, -- TODO info: was integer
    "time_created" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, -- TODO info: default was not present
    "time_updated" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP, -- TODO info: default was not present
    "created_by" integer NOT NULL DEFAULT -1, -- TODO info: default was not present
    CONSTRAINT "featured_pkey" PRIMARY KEY ("id")
);

CREATE TABLE IF NOT EXISTS "sortlog" (
    "id" serial NOT NULL,
    "when" timestamp NOT NULL,
    "path" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "lecture_id" integer NOT NULL,
    "video_id" integer NOT NULL,
    CONSTRAINT "sortlog_pkey" PRIMARY KEY ("id")
);

CREATE TABLE IF NOT EXISTS "sorterrorlog_data" (
    "id" serial NOT NULL,
    "when" timestamp NOT NULL,
    "path" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "course_id" integer NOT NULL,
    "matches" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "deleted" boolean NOT NULL DEFAULT false, -- TODO info: was integer
    "time_updated" timestamp NOT NULL,
    "time_created" timestamp NOT NULL,
    CONSTRAINT "sorterrorlog_data_pkey" PRIMARY KEY ("id")
);

CREATE TABLE IF NOT EXISTS "worker" (
    "hostname" character varying(200) COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "last_ping" timestamp NOT NULL,
    CONSTRAINT "worker_pkey" PRIMARY KEY ("hostname")
);

CREATE TABLE IF NOT EXISTS "jobs" (
    "id" serial NOT NULL,
    "type" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    "priority" integer NOT NULL DEFAULT 0,
    "queue" character varying(20) COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT 'default',
    "state" character varying(255) COLLATE "pg_catalog"."und-x-icu" NOT NULL DEFAULT 'ready',
    "time_finished" timestamp DEFAULT NULL,
    "time_scheduled" timestamp DEFAULT NULL,
    "time_created" timestamp NOT NULL,
    "last_ping" timestamp DEFAULT NULL,
    "worker" text COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "data" text COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "status" text COLLATE "pg_catalog"."und-x-icu" DEFAULT NULL,
    "canceled" boolean DEFAULT false, -- TODO not null
    CONSTRAINT "jobs_pkey" PRIMARY KEY ("id")
);

CREATE TABLE IF NOT EXISTS "responsible" (
    "id" serial NOT NULL,
    "course_id" integer NOT NULL,
    "user_id" integer NOT NULL,
    CONSTRAINT "responsible_pkey" PRIMARY KEY ("id")
); -- TODO info: this had collation latin1_swedish_ci
CREATE UNIQUE INDEX IF NOT EXISTS "responsible_course_id_user_id_index" ON "responsible" ("course_id","user_id");

CREATE TABLE IF NOT EXISTS "feedback" (
    "id" serial NOT NULL,
    "time_created" timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "email" character varying(128) DEFAULT NULL,
    "text" text COLLATE "pg_catalog"."und-x-icu" NOT NULL,
    CONSTRAINT "feedback_pkey" PRIMARY KEY ("id")
);

CREATE VIEW "courses" AS
    SELECT *
    FROM "courses_data"
    WHERE NOT "courses_data"."deleted";
-- TODO Currently there also exists a lectures_old view without joins
CREATE VIEW "lectures" AS
    SELECT "lectures_data".*
    FROM "lectures_data"
    JOIN "courses_data" ON ("courses_data"."id" = "course_id")
    WHERE NOT ("lectures_data"."deleted" OR "courses_data"."deleted");
CREATE VIEW "videos" AS
    SELECT *
    FROM "videos_data"
    WHERE NOT "videos_data"."deleted";
/* -- TODO current does not have the joins
CREATE VIEW "videos" AS
    SELECT "videos_data".*
    FROM "videos_data"
    JOIN "lectures_data" ON ("lectures_data"."id" = "lecture_id")
    JOIN "courses_data" ON ("courses_data"."id" = "course_id")
    WHERE NOT ("videos_data"."deleted" OR "lectures_data"."deleted" OR "courses_data"."deleted")
-- TODO the semicolon is missing here, because pgloader apparently can<insert apostrophe>t properly handle comments (I can?t even write an apostrophe here?!)
*/
CREATE VIEW "sorterrorlog" AS
    SELECT *
    FROM "sorterrorlog_data"
    WHERE NOT "sorterrorlog_data"."deleted";
