from api.objects.object import ObjectClass
from api.objects.fields import SimpleObjectColumnField, FeaturedDisplayPriorityField, ListField, ViewPermissionsField
from api.objects.types import *
from api.objects.type import IntToStringType


CLASS_ANNOUNCEMENT = ObjectClass(
    "announcement",
    [
        SimpleObjectColumnField(
            "type",
            True,
            TYPE_LEGACY_ANNOUNCEMENT_TYPE,
            "level",
            "info_main_page"
        ),
        # SimpleObjectColumnField(   # Currently not represented in db
        #     "visibility",
        #     TYPE_ANNOUNCEMENT_VISIBILITY,
        #     "",
        #     True,
        #     True,
        #     True
        # ),
        SimpleObjectColumnField(
            "text",  # In Spec
            True,
            TYPE_STRING_LONG,
            "text"
        ),
        SimpleObjectColumnField(
            "may_be_visible",
            True,
            TYPE_BOOLEAN,
            "visible",
            False
        ),
        SimpleObjectColumnField(
            "publish_time",
            True,
            DatetimeType(True),
            "time_publish",
            (None, )
        ),
        SimpleObjectColumnField(
            "expiration_time",
            True,
            DatetimeType(True),
            "time_expire",
            (None, )
        )
    ],
    True,
    True,
    True,
    "announcements"
)
CLASS_FEATURED = ObjectClass(
    "featured",
    [
        SimpleObjectColumnField(
            "title",  # In Spec
            True,
            TYPE_STRING_SHORT,
            "title"
        ),
        SimpleObjectColumnField(
            "text",  # In Spec
            True,
            TYPE_STRING_LONG,
            "text"
        ),
        SimpleObjectColumnField(
            "is_visible",  # In Spec
            True,
            TYPE_BOOLEAN,
            "visible",
            False
        ),
        FeaturedDisplayPriorityField()
    ],
    True,
    True,
    True,
    "featured",
    TYPE_FEATURED_TYPE,
    "type",
    {
        "plain": [],
        "image": [
            SimpleObjectColumnField(
                "image_url",
                True,
                TYPE_URL,
                "param"
            )
        ],
        "lecture": [
            SimpleObjectColumnField(
                "lecture_id",
                True,
                TYPE_LECTURE_ID,
                "param"
            )
        ],
        "course_list": [
            SimpleObjectColumnField(
                "filter_criteria",
                True,
                TYPE_COURSE_FILTER_CRITERIA,
                "param"
            ),
            SimpleObjectColumnField(
                "filter_value",
                True,
                TYPE_STRING_SHORT,
                "param2"
            )
        ]
    }
)
CLASS_COURSE = ObjectClass(
    "course",
    [
        SimpleObjectColumnField(
            "full_name",  # In Spec
            True,
            TYPE_STRING_SHORT,
            "title"
        ),
        SimpleObjectColumnField(
            "short_name",  # In Spec
            True,
            TYPE_STRING_SHORT,
            "short"
        ),
        SimpleObjectColumnField(
            "semester",  # In Spec
            True,
            TYPE_SEMESTER_STRING,
            "semester"
        ),
        SimpleObjectColumnField(
            "organizer",  # In Spec
            True,
            TYPE_STRING_SHORT,
            "organizer"
        ),
        SimpleObjectColumnField(
            "description",  # In Spec
            True,
            TYPE_STRING_LONG,
            "description",
            ""
        ),
        SimpleObjectColumnField(
            "is_visible",
            True,
            TYPE_BOOLEAN,
            "visible",
            False
        ),
        SimpleObjectColumnField(
            "is_listed",
            True,
            TYPE_BOOLEAN,
            "listed",
            True
        ),
        SimpleObjectColumnField(
            "external",  # TODO
            True,
            TYPE_BOOLEAN,
            "external",
            False
        ),
        SimpleObjectColumnField(
            "allow_download",
            True,
            TYPE_BOOLEAN,
            "downloadable",
            True
        ),
        SimpleObjectColumnField(
            "automatically_create_media_source_for_encoded_file",  # TODO
            True,
            TYPE_BOOLEAN,
            "autopublish",
            False
        ),
        SimpleObjectColumnField(
            "make_new_videos_visible_by_default",  # TODO
            True,
            TYPE_BOOLEAN,
            "autovisible",
            False
        ),
        SimpleObjectColumnField(
            "show_chapters_on_course",
            True,
            TYPE_BOOLEAN,
            "coursechapters",
            True
        ),
        SimpleObjectColumnField(
            "id_string",
            True,
            TYPE_COURSE_ID_STRING,
            "handle"
        ),
        SimpleObjectColumnField(
            "topic",
            True,
            TYPE_STRING_SHORT,
            "subject"
        ),
        SimpleObjectColumnField(
            "internal_comment",
            True,
            TYPE_STRING_LONG,
            "internal",
            ""
        ),
        SimpleObjectColumnField(
            "authentication_information",
            True,
            TYPE_STRING_LONG,
            "login_info",
            ""
        ),
        ListField(
            "responsible",
            True,
            "user_id_list",
            TYPE_USER_ID,
            "responsible",
            "course_id",
            "user_id",
            []
        ),
        ViewPermissionsField(
            "view_permissions",
            True,
            False
        )
    ],
    True,
    True,
    True,
    "courses_data"
)
CLASS_LECTURE = ObjectClass(
    "lecture",
    [
        SimpleObjectColumnField(
            "title",  # In Spec
            True,
            TYPE_STRING_SHORT,
            "title"
        ),
        SimpleObjectColumnField(
            "speaker",  # In Spec
            True,
            TYPE_STRING_SHORT,
            "speaker",
            ""
        ),
        SimpleObjectColumnField(
            "location",  # In Spec
            True,
            TYPE_STRING_SHORT,
            "place",
            ""
        ),
        SimpleObjectColumnField(
            "time",  # In Spec
            True,
            TYPE_DATETIME,
            "time"
        ),
        SimpleObjectColumnField(
            "duration",  # In Spec
            True,
            TYPE_DURATION,
            "duration"
        ),
        SimpleObjectColumnField(
            "description",  # In Spec
            True,
            TYPE_STRING_LONG,
            "comment",
            ""
        ),
        SimpleObjectColumnField(
            "no_recording",  # In Spec
            True,
            TYPE_BOOLEAN,
            "norecording",
            False
        ),
        SimpleObjectColumnField(
            "livestream_planned",  # TODO (not in api docs)
            True,
            TYPE_BOOLEAN,
            "live",
            False
        ),
        SimpleObjectColumnField(
            "is_visible",  # In Spec
            True,
            TYPE_BOOLEAN,
            "visible",
            True
        ),
        SimpleObjectColumnField(
            "internal_comment",  # In Spec
            True,
            TYPE_STRING_LONG,
            "internal",
            ""
        ),
        ViewPermissionsField(
            "view_permissions",
            True,
            True
        ),
    ],
    True,
    True,
    True,
    "lectures_data",
    parent_classes=[(CLASS_COURSE, "course_id")]
)
CLASS_PERMISSION = ObjectClass(  # Not in API spec but needed for backwards compatibility (with the changelog)
    "permission",
    [],
    True,
    True,
    True,
    "perm",
    TYPE_PERMISSION_TYPE,
    "type",
    {
        "public": [],
        "password": [
            SimpleObjectColumnField(
                "username",  # In Spec
                True,
                TYPE_STRING_SHORT,
                "param1"
            ),
            SimpleObjectColumnField(
                "password",  # In Spec
                True,
                TYPE_STRING_SHORT,
                "param2"
            )
        ],
        "moodle": [
            SimpleObjectColumnField(
                "moodle_course_id",  # In Spec
                True,
                IntToStringType(),
                "param1"
            )
        ],
        "rwth": [],
        "fsmpi": [],
        "none": []
    },
    [(CLASS_COURSE, "course_id"), (CLASS_LECTURE, "lecture_id")]
)
CLASS_CHAPTER = ObjectClass(
    "chapter",
    [
        SimpleObjectColumnField(
            "name",  # In Spec
            True,
            TYPE_STRING_SHORT,
            "text"
        ),
        SimpleObjectColumnField(
            "start_time",  # In Spec
            True,
            TYPE_TIMESTAMP,
            "time"
        ),
        SimpleObjectColumnField(
            "is_visible",  # In Spec
            True,
            TYPE_BOOLEAN,
            "visible"
        )
    ],
    True,
    True,
    True,
    "chapters",
    parent_classes=[(CLASS_LECTURE, "lecture_id")]
)
CLASS_MEDIA_SOURCE = ObjectClass(
    "media_source",
    [
        SimpleObjectColumnField(
            "comment",  # In Spec
            True,
            TYPE_STRING_LONG,
            "comment"
        ),
        SimpleObjectColumnField(
            "is_visible",  # In Spec
            True,
            TYPE_BOOLEAN,
            "visible"
        ),
        SimpleObjectColumnField(
            "internal_comment",  # In Spec
            True,
            TYPE_STRING_LONG,
            "internal"
        )
    ],
    True,
    False,
    True,
    "videos_data",
    parent_classes=[(CLASS_LECTURE, "lecture_id")]
)

object_classes_by_id: dict[str, ObjectClass] = {obj.api_id: obj for obj in [
    CLASS_ANNOUNCEMENT, CLASS_FEATURED,
    CLASS_COURSE, CLASS_LECTURE, CLASS_PERMISSION,
    CLASS_CHAPTER, CLASS_MEDIA_SOURCE
]}
